==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/e2_pane.h <==
/* $Id: e2_pane.h 1064 2005-08-22 04:52:22Z tpgww $
 *
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_PANE_H
 #define E2_PANE_H

#include "emelfm2.h"
#include "e2_option.h"
#include "e2_toolbar.h"

typedef struct _E2_PaneRuntime
{
	gchar *name;	//"pane1" or "pane2" internal name, not translated
	E2_OptionSet *set;

	GtkWidget *outer_box;
	GtkWidget *inner_box;
	GtkWidget *pane;
	GtkWidget *focus_widget;
#ifdef E2_FAM
	gint FAMreq;	//FAM request id used for this pane
#endif
	struct _FileView *view;  //FIXME = for some reason, FileView *view causes error !!
//	GtkWidget *parent_box;
	gchar *path;	//utf-8 string, same as *view->dir
	GList *history;
	gint history_cur;
	E2_ToolbarRuntime toolbar;
	E2_OptionSet *opt_transparent;
	E2_OptionSet *opt_use_startup;
	E2_OptionSet *opt_startup;
	GHookList hook_change_dir;
} E2_PaneRuntime;

void e2_pane_goto_choice (E2_PaneRuntime *rt, gpointer actionrt_data, GtkWidget *from);
gboolean e2_pane_cd_checks (gchar *path);
void e2_pane_activate_other ();
void e2_pane_change_dir (E2_PaneRuntime *rt, gchar *path);
void e2_pane_create (E2_PaneRuntime *rt);
void e2_pane_create_part (E2_PaneRuntime *rt);
void e2_pane_create_option_data (E2_PaneRuntime *rt);
//void e2_pane_destroy (E2_PaneRuntime *rt);
//void e2_pane_recreate (E2_PaneRuntime *rt);
// initialisation things
void e2_pane_flag_active (void);
//void e2_pane_flag_inactive (void);
void e2_pane_actions_register (void);
void e2_pane_options_register (gint num);

#endif //ndef E2_PANE_H

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/src/e2_pane.h <==
/* $Id: e2_pane.h 1438 2005-12-15 11:57:06Z tpgww $
 *
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_PANE_H
 #define E2_PANE_H

#include "emelfm2.h"
#include "e2_option.h"
#include "e2_toolbar.h"

typedef struct _E2_PaneRuntime
{
	gchar *name;	//"pane1" or "pane2" internal name, not translated
	E2_OptionSet *set;

	GtkWidget *outer_box;
	GtkWidget *inner_box;
	GtkWidget *pane_sw;
	GtkWidget *focus_widget;
#ifdef E2_FAM
	gint FAMreq;	//FAM request id used for this pane
#endif
	struct _FileView *view;  //FIXME = for some reason, FileView *view causes error !!
	gchar *path;	//utf-8 string, generally same as *view->dir
	GList *history;
	guint history_cur;
	E2_ToolbarRuntime toolbar;
	E2_OptionSet *opt_transparent;
	E2_OptionSet *opt_use_startup;
	E2_OptionSet *opt_startup;
	GHookList hook_change_dir;
} E2_PaneRuntime;

void e2_pane_goto_choice (E2_PaneRuntime *rt, gpointer actionrt_data, GtkWidget *from);
gboolean e2_pane_cd_checks (gchar *path);
void e2_pane_activate_other_action (void);
void e2_pane_activate_other ();
void e2_pane_change_dir (E2_PaneRuntime *rt, gchar *path);
void e2_pane_create (E2_PaneRuntime *rt);
void e2_pane_create_part (E2_PaneRuntime *rt);
void e2_pane_create_option_data (E2_PaneRuntime *rt);
//void e2_pane_destroy (E2_PaneRuntime *rt);
//void e2_pane_recreate (E2_PaneRuntime *rt);
// initialisation things
void e2_pane_flag_active (void);
//void e2_pane_flag_inactive (void);
void e2_pane_actions_register (void);
void e2_pane_options_register (gint num);

#endif //ndef E2_PANE_H
